% Phyloarray data

\name{Phylodata}
\docType{data}
\alias{scans}

\non_function{}

\title{
  Phyloarray example data
}

\format{
  Example data (scans), which is the result from \code{init.data2()}. It
  contains the data of one slide in two colors, washed at nine different
  temperatures.
}

\description{
  }

\author{
  Kurt Sys (\email{kurt.sys@advalvas.be})
}

\seealso{
  \code{\link[phyloarray]{Scandataraw}}

  \code{\link[phyloarray]{init.data}}
}

\keyword{
  datasets
  Phylodata
  scans
}

\examples{
  # load data from \code{scans <- init.data2()}
  data(Phylodata)

  # The attributes of the object \code{scans}
  attributes(scans)

  # The first 50 red values for the different scans
  scans$R[1:10,]

  # The names of the probes
  scans$ID

  # To see the valeus of probe \code{NONEUB_338}
  # All probes are present in triplicate (=> 3 rows)
  scans$R[scans$ID=="NONEUB_338",]
} 



\eof
% probes file

\name{Probes.csv}
\docType{data}
\alias{Probes}

\non_function{}

\title{
  List of probes and probe-ID's.
}

\format{
  A \code{.csv}-file containing the probenames and probe-ID's of
  matches, mismatches, ... The file should contain at least 2 columns,
  with the first column named "Probename". The names of the next columns
  can be chosen, and could be something like "Matchprobe",
  "Mismatchprobe1" and "Mismachprobe2".
}

\description{
  }

\author{
  Kurt Sys (\email{kurt.sys@advalvas.be})
}

\seealso{
  \code{\link[base]{read.csv}}
}

\keyword{
  datasets
  probes
}

\eof
% Raw data-objects

\name{Scandataraw}
\docType{data}

\alias{scan1}
\alias{scan2}
\alias{scan3}

\non_function{}

\title{
  Raw data
}

\description{
  Load the raw example data of one slide (two colors) washed at three
  different temperatures (scan1, scan2, scan3). 
}

\format{3 objects containing raw genepix data}

\author{
  Kurt Sys (\email{kurt.sys@advalvas.be})
}

\seealso{
  \code{\link[phyloarray]{Phylodata}}

  \code{\link[phyloarray]{read.genepix}}
}

\keyword{
  datasets
}

\examples{
  data(Scandataraw)

  # To see the loaded objects
  ls()

  # The header fields of a genepix-file
  scan1$Header

  # The names of the genepix data fields
  names(scan1$Data)
} 

\eof
% Read probes and add to object

\name{calcbackground}

\alias{calcbackground}

\title{
  Calculate background
}

\description{
  Background values are calculated based on empty spots. The values for
  non-empty spots are calculated by an interpolation procedure. 
}

\usage{
  calcbackground(datalist, emptyfield="empty")
}

\arguments{
  \item{datalist}{An object of type \code{phyloarray}}
  \item{emptyfield}{ID of the spots which are empty, i.e. the spots
	 that are used for background calculation or spots which shouldn't
	 give any signal.}
}

\details{
  The function calculates the background using an kriging algorithm. It
  is important to note that only the spots with \code{ID==emptyfield}
  are used and that badspots, i.e. spots with a sd/signal<cutoff are
  removed from background calculation.

  Other or more flexible interpolation procedures might be included in
  future versions.
}

\value{
  The function returns the same object as given in 'datalist', but the
  \code{Gb} and \code{Rb} values are replaced by the calculated
  background values.
}

\note{ 
}

\references{
}

\author{
  Kurt Sys (\email{kurt.sys@advalvas.be})
}

\seealso{
  \code{\link[phyloarray]{Scandataraw}}
  \code{\link[phyloarray]{Phylodata}}

  \code{\link[phyloarray]{init.data}}

  \code{\link[phyloarray]{plotbackground}}

  \code{\link[gstat]{krige}}
}

\keyword{
  background
}

\examples{
  # load data \code{Phylodata.RData}, i.e. \code{scans}
  data(Phylodata)

  # histogram of background values before interpolation procedure
  hist(scans$R[,"40"], nclass=50)

  scans <- calcbackground(scans)

  # histogram of background values after interpolation procedure
  hist(scans$R[,"40"], nclass=50)
} 

\eof
% Read probes and add to object

\name{getprobes}

\alias{getprobes}

\title{
  Adding probes to object
}

\description{
  Reads the for each "Probename", all match and mismatch probes from a
  \code{.csv}-file. The fields are normally delimited with a comma, and
  the fields surroundend by quotes.
}

\usage{
  getprobes(datalist, file, header=T, sep=",", quote="\"", fill=T, ...)
}

\arguments{
  \item{datalist}{An object of type \code{phyloarray}}
  \item{file}{The file to be read}
  \item{header}{The first row should contain the columns names. The
	 first columns should be named "Probename". The following columns may
	 have any name, and the user should use these names for further
	 analysis.}
  \item{sep}{The delimiter between field. Standard value is a comma.}
  \item{quote}{The quotes around the field values.}
  \item{fill}{If the number of columns is unequal, blank fields are
	 added.}
  \item{...}{Additional parameters for \code{read.csv}}
}

\value{
  An object of class phyloarray is returned, with attribute
  \code{probes} added. This is a dataframe containing for each
  probename, several match and mismatch probe ID's.
}

\note{ 
}

\references{
}

\author{
  Kurt Sys (\email{kurt.sys@advalvas.be})
}

\seealso{
  \code{\link[phyloarray]{Scandataraw}}
  \code{\link[phyloarray]{Phylodata}}

  \code{\link[phyloarray]{init.data}}

  \code{\link[base]{read.csv}}
}

\keyword{
  probes
}

\examples{
  # load data \code{Phylodata.RData}, i.e. \code{scans}
  data(Phylodata)

  # read the probes from a \code{.csv}-file
  # scans <- getprobes(scans, file="probes.csv")

  # names of the columns
  names(attr(scans, "probes"))

  # the list of probenames and -ID's
  attributes(scans)$probes
} 

\eof
% Find cutoff values for badspots

\name{histcutoffs}

\alias{histcutoffs}

\title{
  Histogram cutoff values
}

\description{
  Calculate cutoff values for standard deviation/signal intensities for
  badspots. A bad spot has high sd/signal intensity. The cutoff value is
  based on a fivenum/boxplot analysis.
}

\usage{
  histcutoffs(datalist, cutat=1.7)
}

\arguments{
  \item{datalist}{An object of type \code{phyloarray} for which the
	 cutoffs should be calculated.}
  \item{cutat}{A value giving how many times the length of the boxplot
	 the cutoff should be set. This is the \code{coef}-argument of the
	 \code{boxplot.stats} function.}
}

\value{
  The return value is the object datalist of class \code{phyloarray}, but with one
  attribute added, i.e. "cutoff"
}

\details{
  For the function, the standard deviation/signal values are calculated
  and log-transformed. Using the log-transformed values, a boxplot is
  calculated, with the coefficient for outliers at \code{cutat} times
  the length of the box itself.

  Concerning \code{cutat}: If(!) the log-transformed values are normal
  distributed, setting \code{cutat} to 1.0, means having a certainty of
  97.7250\% of no false negatived. 1.35 has 99.3890\% certainty, 1.7 has
  99.8650\% certainty and 2.5 has 99.9968\% certainty of no false
  negatives. It is stressed that these values are only true for normal
  distributions!
}

\note{ 
}

\references{
}

\author{
  Kurt Sys (\email{kurt.sys@advalvas.be})
}

\seealso{
  \code{\link[phyloarray]{Scandataraw}}
  \code{\link[phyloarray]{Phylodata}}

  \code{\link[phyloarray]{init.data}}

  \code{\link[phyloarray]{calcbackground}}

  \code{\link[base]{boxplot.stats}}
  \code{\link[base]{boxplot}}
  \code{\link[base]{fivenum}}
}

\keyword{
  histogram
  boxplot
  cutoff
}

\examples{
  # load data \code{Phylodata.RData}, i.e. \code{scans}
  data(Phylodata)

  # show some histograms
  hist(scans$Rsd[,1]/scans$R[,1], nclass=10000, xlim=c(0,5))
  hist(scans$Gsd[,1]/scans$G[,1], nclass=10000, xlim=c(0,1))

  # calculate cutoff values
  scans <- histcutoffs(scans, cutat=2.5)

  # the cutoff values
  attr(scans, "cutoff")

  # which gives the same as
  attributes(scans)$cutoff
} 

\eof
% Read important fields from raw data-objects

\name{init.data}

\alias{init.data2}

\title{
  Initialize data
}

\description{
  Read the important fields of the several raw data-objects and store
  them in a new object (with class "phyloarray"). This function also
  reads the temperatures from the headers.
}

\usage{
  init.data2()
}

\arguments{
}

\value{
  The function returns an object of class \code{phyloarray}. It is a list
  with values R (red signal), G (green signal), Rb (red background
  signal), Gb (green background signal), Rsd (standard deviation of red
  signal) and Gsd (standard deviation of green signal). The standard
  deviation values are used to mark bad spots (based on sd/signal). The
  list contains also X- and Y-values of the spots (to calculate
  background, if necessary) and the ID's of the probes.
  Each field R, G, Rb, Gb, Rsd and Gsd is a datamatrix with in the rows
  the values for the different probes and in the columns the different
  temperatures. To a larger extent, the columns may be other factors to
  (such as time-related values), but they are designed to be used for
  making melting curves and analysis on the melting curves.
}

\note{
  Since there is a function \code{init.data} in \code{sma}, this function has
  been calles \code{init.data2}. It is largely the same function, but some
  fields are added to make the phylogenetic analysis of melting curves
  more easy.

  Some examples of basic handling of an object of class phyloarray is in
  the help-file \code{Phylodata}
}

\references{
}

\author{
  Kurt Sys (\email{kurt.sys@advalvas.be})
}

\seealso{
  \code{\link[phyloarray]{Scandataraw}}
  \code{\link[phyloarray]{Phylodata}}

  \code{\link[phyloarray]{read.genepix}}
  
  \code{\link[phyloarray]{getprobes}}
}

\keyword{
  initialize data
  phyloarray
}

\examples{
  # load the saved raw data from this package:
  # data(Scandataraw)

  # scans <- init.data2()

  # Are you creating a new data matrix or adding new array data
  # to a prexisting data matrix? 
  # Enter "n" for creating  and "a" for adding new array data: n
  # Do the names of all your datasets have the following format: 
  # prefix1, prefix2, prefix3?, ... Here prefix can be any name, 
  # but the suffixes must be integers 1,2, ..., # of arrays. 
  # Enter "y" for yes, "n" for no: y
  # Enter the prefix:scan
  # Enter the number of arrays to be processed:3
  # Enter the name of Cy3 raw data: Gmed
  # Enter the name of Cy3 background: Gbmed
  # Enter the name of Cy3 intensity standard deviation: GSD
  # Enter the name of Cy5 raw data: Rmed
  # Enter the name of Cy5 background: Rbmed
  # Enter the name of Cy5 intensity standard deviation: RSD
  # Enter the name of the ID/probenames field: ID
  # Enter the X values for probe positions: Column
  # Enter the Y values for probe positions: Row
  # Finished creating the dataset.



  # load data \code{Phylodata.RData}, i.e. \code{scans}
  data(Phylodata)

  names(scans)

  attributes(scans)

} 



\eof
% Plot background

\name{plotbackground}

\alias{plotbackground}

\title{
  Plot background
}

\description{
  Make a plot of the background of a certain color and scan.
}

\usage{
  plotbackground(datalist, dye="R", scan=1)
}

\arguments{
  \item{datalist}{An object of type \code{phyloarray}}
  \item{dye}{The dye of which the background should be plotted, i.e. "R"
	 or "G".}
  \item{scan}{The scan of which the background should be plotted. This
	 may be a number (the number of the column) or a string (name of the column).}
}

\value{
}

\note{ 
}

\references{
}

\author{
  Kurt Sys (\email{kurt.sys@advalvas.be})
}

\seealso{
  \code{\link[phyloarray]{Scandataraw}}
  \code{\link[phyloarray]{Phylodata}}

  \code{\link[phyloarray]{calcbackground}}

  \code{\link[base]{filled.contour}}
}

\keyword{
  background calculation
}

\examples{
  # load data \code{Phylodata.RData}, i.e. \code{scans}
  data(Phylodata)

  # plot background for red, temperature=58C
  plotbackground(scans, dye="R", scan="58")

  # this is the same
  plotbackground(scans, scan="58")

  # and this too
  plotbackground(scans, scan=3)
} 

\eof
% Plot meltingcurve

\name{plotmeltingcurve}

\alias{plotmeltingcurve}

\title{
  Plot melting curve
}

\description{
  Make a plot of a melting curve. 
}

\usage{
  plotmeltingcurve(datalist, dye="R", probe=NULL)
}

\arguments{
  \item{datalist}{An object of type \code{phyloarray}}
  \item{dye}{The dye of which the background should be plotted, i.e. "R"
	 or "G".}
  \item{probe}{The name of the probe ('Probename') which should be
	 plotted.}
}

\details{
  At present date, only the signal/background ratio is calculated and
  plotted. In the future, other methods may be included.

  The probe-ID's to be plotted are taken from the list of probes. If
  more than one probe has the same 'Probename', all the probes are
  plotted in the figure, using different point character (from type 1 to
  ...). Each next column, i.e. ID of probe of the same 'Probename'
  (match, mismatch, ...) is plotted using a different color, going from
  color 1 to ... See \code{\link[base]{par}} and
  \code{\link[base]{plot}} for more information about characters and
  colors.
  
}

\value{
}

\note{ 
}

\references{
}

\author{
  Kurt Sys (\email{kurt.sys@advalvas.be})
}

\seealso{
  \code{\link[phyloarray]{Scandataraw}}
  \code{\link[phyloarray]{Phylodata}}

  \code{\link[base]{plot}}
  \code{\link[base]{lines}}
  \code{\link[base]{par}}
}

\keyword{
  melting curve
}

\examples{
  # load data \code{Phylodata.RData}, i.e. \code{scans}
  data(Phylodata)

  # for calculation of histogram cutoffs for good/bad spots
  # scans <- histcutoffs(scans)
  #
  # if background calculation is necessary
  # scans <- calcbackgroud(scans)

  plotmeltingcurve(scans, probe="Bacteria1")
} 

\eof
% Print phyloarray-object information

\name{print.phyloarray}

\alias{print.phyloarray}

\title{
  Print phylogeny information
}

\description{
  Prints information of an object of "phyloarray"-class. One should
  however use the generic function \code{print}, which will
  use this function for objects of class "phyloarray".
  
}

\usage{
  print.phyloarray(x, ...)
}

\arguments{
  \item{x}{An object of type \code{phyloarray}}
  \item{...}{Not used}
}

\author{
  Kurt Sys (\email{kurt.sys@advalvas.be})
}

\seealso{
  \code{\link[base]{print}}
}

\keyword{
  }

\examples{
  # load data \code{Phylodata.RData}, i.e. \code{scans}
  data(Phylodata)

  print(scans)
} 

\eof
% Find probenames

\name{probes2probenames}

\alias{probes2probenames}

\title{
  Find probenames
}

\description{
  Search probenames if a probe-ID is known.
}

\usage{
  probes2probenames(datalist, probe)
}

\arguments{
  \item{datalist}{An object of type \code{phyloarray}}
  \item{probe}{ID of the probe of which the probename is searched.}
}

\value{
}

\note{ 
}

\references{
}

\author{
  Kurt Sys (\email{kurt.sys@advalvas.be})
}

\seealso{
  \code{\link[phyloarray]{Scandataraw}}
  \code{\link[phyloarray]{Phylodata}}

  \code{\link[base]{plot}}
  \code{\link[base]{lines}}
  \code{\link[base]{par}}
}

\keyword{
  melting curve
}

\examples{
  # load data \code{Phylodata.RData}, i.e. \code{scans}
  data(Phylodata)

  # for calculation of histogram cutoffs for good/bad spots
  # scans <- histcutoffs(scans)
  #
  # if background calculation is necessary
  # scans <- calcbackgroud(scans)

  # sort scans on green
  scans <- sortdata(scans, dye="G")

  plotprobes <- probes2probenames(scans, scans$ID[1:25])

  for (p in plotprobes)
    plotmeltingcurve(scans, dye="G", p)
} 

\eof
% Read genepix-files

\name{read.genepix}

\alias{read.genepix2}

\title{
  Reading genepix-file
}

\description{
  Read a genepix-file ('.gpr') and stores result in a list containing
  'header' and 'data'. 
}

\usage{
  read.genepix2(file, temperature=42, buffer=data.frame(na=0.97, f=35))
}

\arguments{
  \item{file}{The name of the file to be read. The extension should be
	 given.}
  \item{temperature}{The temperature of hybridization (or washing)
	 step. Since there's a focus on melting curves, this is important and
	 the value given here will be added to the header.}
  \item{buffer}{Buffer contents used during hybridization (or
	 washing). This is not used anywhere yet, but it might e.g. to
	 calculate the theoretical melting/annealing temperature based on the
	 sequence and the buffer content. 'na' is the salt (Na)--content and
	 'f' the formamide concentration (in percent).}
}

\value{
  The function returns a list containing:
  \item{Header}{A list with the header fields of the \code{.gpr}-file, with
	 additional information concerning the hybridization temperature and
	 buffer contents (given as arguments to the function.}
  \item{Data}{A data matrix with the data in a \code{.gpr}-file. This
	 includes median and mean values for fore- and background, as well as
	 probe ID's, standard deviations, X and Y	values etc.}
}

\note{
  Since there is a function read.genepix in \code{sma}, this function has
  been called \code{read.genepix2}. It must be noted that for new versions of
  genepix, the function in the \code{sma}-package doesn't work (since more
  columns are added). This function works for both, but I have really no
  idea how the future will be... Anyway I tried to make it as general as
  possible.

  Data from other image processing software (e.g. Spot) may be imported
  using the package \code{sma}. In that case, one should know the names
  of the fields of the red/green signals etc.
}

\references{
}

\author{
  Kurt Sys (\email{kurt.sys@advalvas.be})
}

\seealso{
  \code{\link[phyloarray]{Scandataraw}}
  \code{\link[phyloarray]{Phylodata}}
  
  \code{\link[phyloarray]{init.data}}
}

\keyword{
  genepix file
  raw data
}

\examples{
  # There are \code{.gpr}-files in the data-section of this package
  #
  # scan1 <- read.genepix2("<file_scan.at.22degrees>", temperature=22)
  # ...
  # scan3 <- read.genepix2("<file_scan.at.58degrees>", temperature=58)
  #
  # 
  # or, e.g.:
  #
  # scan <- 1
  # for (t in c(22+0:2*18)) {
  #   assign(paste("scan", slide, sep=""),
  #          read.genepix2(paste("wash", t, ".gpr", sep=""), temperature=t))
  #   scan <- scan+1
  # }
}

\eof
% Sort data

\name{sortdata}

\alias{sortdata}

\title{
  Sorting data
}

\description{
  Sort data from high to low, based on the data of the first column in
  each data matrix.
}

\usage{
  sortdata(datalist, dye="R", method="subtrbg")
}

\arguments{
  \item{datalist}{An object of type \code{phyloarray}}
  \item{dye}{The dye used for sorting data, i.e. "R" or "G".}
  \item{method}{The method for sorting. Only one method is included yet,
  i.e. \code{"subtrbg"}, in which the data is sorted by subtracting the
  background from the signal. More methods will be included in the future.}
}

\value{
}

\note{ 
}

\references{
}

\author{
  Kurt Sys (\email{kurt.sys@advalvas.be})
}

\seealso{
  \code{\link[phyloarray]{Scandataraw}}
  \code{\link[phyloarray]{Phylodata}}

  \code{\link[base]{plot}}
  \code{\link[base]{lines}}
  \code{\link[base]{par}}
}

\keyword{
  melting curve
}

\examples{
  # load data \code{Phylodata.RData}, i.e. \code{scans}
  data(Phylodata)

  # for calculation of histogram cutoffs for good/bad spots
  # scans <- histcutoffs(scans)
  #
  # if background calculation is necessary
  # scans <- calcbackgroud(scans)

  # the first 25 rows of sorted scans$R
  sortdata(scans)$R[1:25, ]

  # and their ID's
  sortdata(scans)$ID[1:25]

  # sort scans on green
  scans <- sortdata(scans, dye="G")

  # check probes2probenames
} 

\eof
